@@ -7,7 +7,7 @@ set -eux -o pipefail
 test -f /etc/alpine-release || exit 0
 
 # Data directories that should be persisted across reboots
-DATADIRS="/etc /home /tmp /usr/local /var/lib"
+DATADIRS="/etc /home /root /tmp /usr/local /var/lib"
 
 # When running from RAM try to move persistent data to data-volume
 # FIXME: the test for tmpfs mounts is probably Alpine-specific
@@ -43,6 +43,8 @@ if [ "$(awk '$2 == "/" {print $3}' /proc/mounts)" == "tmpfs" ]; then
 					mkdir -p "${DIR}" "${DEST}"
 					mv "${DIR}" "${DEST}"
 				done
+				# Make sure all data moved to the persistent volume has been committed to disk
+				sync
 				break
 			fi
 		done
