@@ -4,9 +4,10 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"net"
+	"net/url"
 	"os"
 	"path/filepath"
-	"regexp"
 	"strconv"
 	"strings"
 	"time"
@@ -23,6 +24,16 @@ import (
 	"github.com/sirupsen/logrus"
 )
 
+var netLookupIP = func(host string) []net.IP {
+	ips, err := net.LookupIP(host)
+	if err != nil {
+		logrus.Debugf("net.LookupIP %s: %s", host, err)
+		return nil
+	}
+
+	return ips
+}
+
 func setupEnv(y *limayaml.LimaYAML) (map[string]string, error) {
 	// Start with the proxy variables from the system settings.
 	env, err := osutil.ProxySettings()
@@ -50,16 +61,25 @@ func setupEnv(y *limayaml.LimaYAML) (map[string]string, error) {
 			}
 		}
 	}
-	// Replace "localhost" in proxy settings with the gateway address
-	localhostRegexes := []*regexp.Regexp{
-		regexp.MustCompile(`\blocalhost\b`),
-		regexp.MustCompile(`\b127.0.0.1\b`),
-	}
+	// Replace IP that IsLoopback in proxy settings with the gateway address
 	for _, name := range append(lowerVars, upperVars...) {
 		value, ok := env[name]
 		if ok && !strings.EqualFold(name, "no_proxy") {
-			for _, re := range localhostRegexes {
-				value = re.ReplaceAllString(value, qemu.SlirpGateway)
+			u, err := url.Parse(value)
+			if err != nil {
+				logrus.Warnf("Ignoring invalid proxy %q=%v: %s", name, value, err)
+				continue
+			}
+
+			for _, ip := range netLookupIP(u.Hostname()) {
+				if ip.IsLoopback() {
+					newHost := qemu.SlirpGateway
+					if u.Port() != "" {
+						newHost = net.JoinHostPort(newHost, u.Port())
+					}
+					u.Host = newHost
+					value = u.String()
+				}
 			}
 			if value != env[name] {
 				logrus.Infof("Replacing %q value %q with %q", name, env[name], value)
@@ -219,6 +239,8 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 		args.CACerts.Trusted = append(args.CACerts.Trusted, cert)
 	}
 
+	args.BootCmds = getBootCmds(y.Provision)
+
 	if err := ValidateTemplateArgs(args); err != nil {
 		return err
 	}
@@ -235,20 +257,22 @@ func GenerateISO9660(instDir, name string, y *limayaml.LimaYAML, udpDNSLocalPort
 				Path:   fmt.Sprintf("provision.%s/%08d", f.Mode, i),
 				Reader: strings.NewReader(f.Script),
 			})
+		case limayaml.ProvisionModeBoot:
+			continue
 		default:
 			return fmt.Errorf("unknown provision mode %q", f.Mode)
 		}
 	}
 
-	if guestAgentBinary, err := GuestAgentBinary(*y.Arch); err != nil {
+	guestAgentBinary, err := GuestAgentBinary(*y.Arch)
+	if err != nil {
 		return err
-	} else {
-		defer guestAgentBinary.Close()
-		layout = append(layout, iso9660util.Entry{
-			Path:   "lima-guestagent",
-			Reader: guestAgentBinary,
-		})
 	}
+	defer guestAgentBinary.Close()
+	layout = append(layout, iso9660util.Entry{
+		Path:   "lima-guestagent",
+		Reader: guestAgentBinary,
+	})
 
 	if nerdctlArchive != "" {
 		nftgzR, err := os.Open(nerdctlArchive)
@@ -289,3 +313,20 @@ func getCert(content string) Cert {
 	// return lines
 	return Cert{Lines: lines}
 }
+
+func getBootCmds(p []limayaml.Provision) []BootCmds {
+	var bootCmds []BootCmds
+	for _, f := range p {
+		if f.Mode == limayaml.ProvisionModeBoot {
+			lines := []string{}
+			for _, line := range strings.Split(f.Script, "\n") {
+				if line == "" {
+					continue
+				}
+				lines = append(lines, strings.TrimSpace(line))
+			}
+			bootCmds = append(bootCmds, BootCmds{Lines: lines})
+		}
+	}
+	return bootCmds
+}
