@@ -34,11 +34,16 @@ func (a *HostAgent) setupMounts(ctx context.Context) ([]*mount, error) {
 }
 
 func (a *HostAgent) setupMount(ctx context.Context, m limayaml.Mount) (*mount, error) {
-	expanded, err := localpathutil.Expand(m.Location)
+	location, err := localpathutil.Expand(m.Location)
 	if err != nil {
 		return nil, err
 	}
-	if err := os.MkdirAll(expanded, 0755); err != nil {
+
+	mountPoint, err := localpathutil.Expand(m.MountPoint)
+	if err != nil {
+		return nil, err
+	}
+	if err := os.MkdirAll(location, 0755); err != nil {
 		return nil, err
 	}
 	// NOTE: allow_other requires "user_allow_other" in /etc/fuse.conf
@@ -49,34 +54,35 @@ func (a *HostAgent) setupMount(ctx context.Context, m limayaml.Mount) (*mount, e
 	if *m.SSHFS.FollowSymlinks {
 		sshfsOptions = sshfsOptions + ",follow_symlinks"
 	}
-	logrus.Infof("Mounting %q", expanded)
+	logrus.Infof("Mounting %q on %q", location, mountPoint)
+
 	rsf := &reversesshfs.ReverseSSHFS{
 		Driver:              *m.SSHFS.SFTPDriver,
 		SSHConfig:           a.sshConfig,
-		LocalPath:           expanded,
+		LocalPath:           location,
 		Host:                "127.0.0.1",
 		Port:                a.sshLocalPort,
-		RemotePath:          expanded,
+		RemotePath:          mountPoint,
 		Readonly:            !(*m.Writable),
 		SSHFSAdditionalArgs: []string{"-o", sshfsOptions},
 	}
 	if err := rsf.Prepare(); err != nil {
-		return nil, fmt.Errorf("failed to prepare reverse sshfs for %q: %w", expanded, err)
+		return nil, fmt.Errorf("failed to prepare reverse sshfs for %q on %q: %w", location, mountPoint, err)
 	}
 	if err := rsf.Start(); err != nil {
-		logrus.WithError(err).Warnf("failed to mount reverse sshfs for %q, retrying with `-o nonempty`", expanded)
+		logrus.WithError(err).Warnf("failed to mount reverse sshfs for %q on %q, retrying with `-o nonempty`", location, mountPoint)
 		// NOTE: nonempty is not supported for libfuse3: https://github.com/canonical/multipass/issues/1381
 		rsf.SSHFSAdditionalArgs = []string{"-o", "nonempty"}
 		if err := rsf.Start(); err != nil {
-			return nil, fmt.Errorf("failed to mount reverse sshfs for %q: %w", expanded, err)
+			return nil, fmt.Errorf("failed to mount reverse sshfs for %q on %q: %w", location, mountPoint, err)
 		}
 	}
 
 	res := &mount{
 		close: func() error {
-			logrus.Infof("Unmounting %q", expanded)
+			logrus.Infof("Unmounting %q", location)
 			if closeErr := rsf.Close(); closeErr != nil {
-				return fmt.Errorf("failed to unmount reverse sshfs for %q: %w", expanded, err)
+				return fmt.Errorf("failed to unmount reverse sshfs for %q on %q: %w", location, mountPoint, err)
 			}
 			return nil
 		},
