@@ -29,6 +29,9 @@ const (
 	CIDataISO          = "cidata.iso"
 	BaseDisk           = "basedisk"
 	DiffDisk           = "diffdisk"
+	Kernel             = "kernel"
+	KernelCmdline      = "kernel.cmdline"
+	Initrd             = "initrd"
 	QemuPID            = "qemu.pid"
 	QMPSock            = "qmp.sock"
 	SerialLog          = "serial.log"
